==> estateplat-common-1.2.4-20210127.061800-634-sources.jar: cn/gtmap/estateplat/model/server/core/XxgxScjgQyxx.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/**
 * @author <a href="mailto:qijiadong@gtmap.cn">qijiadong</a>
 * @version 1.0, 2020/11/12
 * @description 省级信息共享-市场监管-企业信息
 */
@Table(name = "xxgx_scjg_qyxx")
public class XxgxScjgQyxx {
    @Id
    private String qyxxid;//企业信息id
    private String qymc;//企业名称
    private String tyshxydm;//统一社会信用代码
    private Date hzrq;//核准如期
    private String zs;//住所
    private String qylx;//企业类型（中文）
    private Date clrq;//成立日期
    private String fddbr;//法定代表人
    private Date jyqxq;//经营期限自
    private String jyfw;//经营范围
    private Date jyqxz;//经营期限至
    private Integer zczb;//注册资本
    private String zczbbz;//注册资本币种（中文）
    private String zch;//注册号
    private String djjg;//登记机关（中文）
    private String djzt;//登记状态（中文）
    private String jdh;//节点号
    private String proid;//项目ID

    public String getQyxxid() {
        return qyxxid;
    }

    public void setQyxxid(String qyxxid) {
        this.qyxxid = qyxxid;
    }

    public String getQymc() {
        return qymc;
    }

    public void setQymc(String qymc) {
        this.qymc = qymc;
    }

    public String getTyshxydm() {
        return tyshxydm;
    }

    public void setTyshxydm(String tyshxydm) {
        this.tyshxydm = tyshxydm;
    }

    public Date getHzrq() {
        return hzrq;
    }

    public void setHzrq(Date hzrq) {
        this.hzrq = hzrq;
    }

    public String getZs() {
        return zs;
    }

    public void setZs(String zs) {
        this.zs = zs;
    }

    public String getQylx() {
        return qylx;
    }

    public void setQylx(String qylx) {
        this.qylx = qylx;
    }

    public Date getClrq() {
        return clrq;
    }

    public void setClrq(Date clrq) {
        this.clrq = clrq;
    }

    public String getFddbr() {
        return fddbr;
    }

    public void setFddbr(String fddbr) {
        this.fddbr = fddbr;
    }

    public Date getJyqxq() {
        return jyqxq;
    }

    public void setJyqxq(Date jyqxq) {
        this.jyqxq = jyqxq;
    }

    public String getJyfw() {
        return jyfw;
    }

    public void setJyfw(String jyfw) {
        this.jyfw = jyfw;
    }

    public Date getJyqxz() {
        return jyqxz;
    }

    public void setJyqxz(Date jyqxz) {
        this.jyqxz = jyqxz;
    }

    public Integer getZczb() {
        return zczb;
    }

    public void setZczb(Integer zczb) {
        this.zczb = zczb;
    }

    public String getZczbbz() {
        return zczbbz;
    }

    public void setZczbbz(String zczbbz) {
        this.zczbbz = zczbbz;
    }

    public String getZch() {
        return zch;
    }

    public void setZch(String zch) {
        this.zch = zch;
    }

    public String getDjjg() {
        return djjg;
    }

    public void setDjjg(String djjg) {
        this.djjg = djjg;
    }

    public String getDjzt() {
        return djzt;
    }

    public void setDjzt(String djzt) {
        this.djzt = djzt;
    }

    public String getJdh() {
        return jdh;
    }

    public void setJdh(String jdh) {
        this.jdh = jdh;
    }

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }
}

==> estateplat-common-1.2.4-20231024.023255-1193-sources.jar: cn/gtmap/estateplat/model/server/core/XxgxScjgQyxx.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/**
 * @author <a href="mailto:qijiadong@gtmap.cn">qijiadong</a>
 * @version 1.0, 2020/11/12
 * @description 省级信息共享-市场监管-企业信息(江苏、安徽)
 */
@Table(name = "xxgx_scjg_qyxx")
public class XxgxScjgQyxx {
    @Id
    private String qyxxid;//企业信息id
    private String qymc;//企业名称
    private String tyshxydm;//统一社会信用代码
    private Date hzrq;//核准如期
    private String zs;//住所，地址
    private String qylx;//企业类型（中文）
    private Date clrq;//成立日期，注册日期
    private String fddbr;//法定代表人，经营者
    private Date jyqxq;//经营期限自，经营开始时间
    private String jyfw;//经营范围
    private Date jyqxz;//经营期限至
    private Integer zczb;//注册资本
    private String zczbbz;//注册资本币种（中文）
    private String zch;//注册号
    private String djjg;//登记机关（中文）
    private String djzt;//登记状态（中文）
    private String jdh;//节点号
    private String proid;//项目ID
    private String qlrid;//权利人ID
    private Date cxsj;//查询时间

    public String getQlrid() {
        return qlrid;
    }

    public void setQlrid(String qlrid) {
        this.qlrid = qlrid;
    }

    public Date getCxsj() {
        return cxsj;
    }

    public void setCxsj(Date cxsj) {
        this.cxsj = cxsj;
    }

    public String getQyxxid() {
        return qyxxid;
    }

    public void setQyxxid(String qyxxid) {
        this.qyxxid = qyxxid;
    }

    public String getQymc() {
        return qymc;
    }

    public void setQymc(String qymc) {
        this.qymc = qymc;
    }

    public String getTyshxydm() {
        return tyshxydm;
    }

    public void setTyshxydm(String tyshxydm) {
        this.tyshxydm = tyshxydm;
    }

    public Date getHzrq() {
        return hzrq;
    }

    public void setHzrq(Date hzrq) {
        this.hzrq = hzrq;
    }

    public String getZs() {
        return zs;
    }

    public void setZs(String zs) {
        this.zs = zs;
    }

    public String getQylx() {
        return qylx;
    }

    public void setQylx(String qylx) {
        this.qylx = qylx;
    }

    public Date getClrq() {
        return clrq;
    }

    public void setClrq(Date clrq) {
        this.clrq = clrq;
    }

    public String getFddbr() {
        return fddbr;
    }

    public void setFddbr(String fddbr) {
        this.fddbr = fddbr;
    }

    public Date getJyqxq() {
        return jyqxq;
    }

    public void setJyqxq(Date jyqxq) {
        this.jyqxq = jyqxq;
    }

    public String getJyfw() {
        return jyfw;
    }

    public void setJyfw(String jyfw) {
        this.jyfw = jyfw;
    }

    public Date getJyqxz() {
        return jyqxz;
    }

    public void setJyqxz(Date jyqxz) {
        this.jyqxz = jyqxz;
    }

    public Integer getZczb() {
        return zczb;
    }

    public void setZczb(Integer zczb) {
        this.zczb = zczb;
    }

    public String getZczbbz() {
        return zczbbz;
    }

    public void setZczbbz(String zczbbz) {
        this.zczbbz = zczbbz;
    }

    public String getZch() {
        return zch;
    }

    public void setZch(String zch) {
        this.zch = zch;
    }

    public String getDjjg() {
        return djjg;
    }

    public void setDjjg(String djjg) {
        this.djjg = djjg;
    }

    public String getDjzt() {
        return djzt;
    }

    public void setDjzt(String djzt) {
        this.djzt = djzt;
    }

    public String getJdh() {
        return jdh;
    }

    public void setJdh(String jdh) {
        this.jdh = jdh;
    }

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }
}
